@@ -38,9 +38,11 @@ public:
 
     RAction(RUser* source, RFile* target, float addedtime);
 
-    bool isFinished();
+    inline bool isFinished() const { return (progress >= 1.0); };
 
     virtual void logic(float dt);
+
+    void drawToVBO(quadbuf& buffer) const ;
     void draw(float dt);
 };
 
