@@ -182,6 +182,12 @@ public:
         this->z = vec.z;
     }
 
+    vec3(const vec2<T>& vec, float z) {
+        this->x = vec.x;
+        this->y = vec.y;
+        this->z = z;
+    }
+
     vec3(T x = 0, T y = 0, T z = 0) {
         this->x = x;
         this->y = y;
@@ -289,6 +295,27 @@ public:
     }
 };
 
+template<class T> class lerp3 : public vec3<T> {
+public:
+    vec3<T> p;
+    vec3<T> l;
+
+    lerp3() : vec3<T>(), p(), l() {
+    }
+
+    lerp3(const vec3<T>& vec) : vec3<T>(vec) {
+    }
+
+    void snap() {
+        p = (vec3<T>) *this;
+    }
+
+    const vec3<T>& lerp(T n) {
+        l = p * n + *this * (1.0-n);
+        return l;
+    }
+};
+
 template<class T> class vec4 {
 public:
     T x;
@@ -358,7 +385,7 @@ public:
     }
 
     bool operator!= (const vec4<T> &vec) const {
-        return (vec.x!=x || vec.y!=y || vec.z!=z || vec.w==w);
+        return (vec.x!=x || vec.y!=y || vec.z!=z || vec.w!=w);
     }
 
     T length2() const {
@@ -423,6 +450,8 @@ typedef vec2<float> vec2f;
 typedef vec3<float> vec3f;
 typedef vec4<float> vec4f;
 
+typedef lerp3<float> lerp3f;
+
 typedef vec2<int> vec2i;
 typedef vec3<int> vec3i;
 typedef vec4<int> vec4i;
