@@ -1148,21 +1148,28 @@ void Gource::processCommit(RCommit& commit, float t) {
 
             if(cf.action != "D") continue;
 
-            RDirNode* dir = root->findDir(cf.filename);
+            std::list<RDirNode*> dirs;
 
-            if(!dir) continue;
+            root->findDirs(cf.filename, dirs);
 
-            //foreach dir files
-            std::list<RFile*> dir_files;
+            for(std::list<RDirNode*>::iterator it = dirs.begin(); it != dirs.end(); it++) {
 
-            dir->getFilesRecursive(dir_files);
+                RDirNode* dir = (*it);
+                
+                //fprintf(stderr, "deleting everything under %s because of %s\n", dir->getPath().c_str(), cf.filename.c_str());
 
-            for(std::list<RFile*>::iterator it = dir_files.begin(); it != dir_files.end(); it++) {
-                RFile* file = *it;
+                //foreach dir files
+                std::list<RFile*> dir_files;
 
-                addFileAction(commit.username, cf.action, file, t);
+                dir->getFilesRecursive(dir_files);
+
+                for(std::list<RFile*>::iterator it = dir_files.begin(); it != dir_files.end(); it++) {
+                    RFile* file = *it;
+
+                    addFileAction(commit.username, cf.action, file, t);
+                }
             }
-
+                
             return;
         }
 
@@ -1857,7 +1864,7 @@ void Gource::drawScene(float dt) {
 
     updateAndDrawEdges();
 
-    draw_edges_time = SDL_GetTicks() - draw_edges_time;  
+    draw_edges_time = SDL_GetTicks() - draw_edges_time;
 
     //draw shadows
 
@@ -1905,7 +1912,7 @@ void Gource::drawScene(float dt) {
 
 void Gource::updateAndDrawEdges() {
     if(gGourceSettings.hide_tree) return;
-        
+
     root->calcEdges();
 
     //switch to 2d
@@ -1945,7 +1952,7 @@ void Gource::updateAndDrawEdges() {
         glUseProgramObjectARB(0);
 
         edge_vbo.draw();
-    
+
     } else {
         root->drawEdgeShadows();
         root->drawEdges();
@@ -2240,9 +2247,6 @@ void Gource::draw(float t, float dt) {
 
     camera.focus();
 
-    glMatrixMode(GL_MODELVIEW);
-    glLoadIdentity();
-
     //check visibility
     root->checkFrustum(frustum);
 
@@ -2449,8 +2453,8 @@ void Gource::draw(float t, float dt) {
 
     // text using the specified font goes here
 
-    glColor4f(gGourceSettings.font_colour.x, gGourceSettings.font_colour.y, gGourceSettings.font_colour.z, 1.0f);
-
+    fontmedium.setColour(vec4f(gGourceSettings.font_colour, 1.0f));
+    
     if(!gGourceSettings.hide_date) {
         fontmedium.draw(display.width/2 - date_x_offset, 20, displaydate);
     }
